summaryrefslogtreecommitdiffstats
path: root/kpresenter/KPrTextObject.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
commitf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (patch)
tree1fc538e179833e62caec21956bfe47a252be5a72 /kpresenter/KPrTextObject.cpp
parent11191ef0b9908604d1d7aaca382b011ef22c454c (diff)
downloadkoffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.tar.gz
koffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kpresenter/KPrTextObject.cpp')
-rw-r--r--kpresenter/KPrTextObject.cpp42
1 files changed, 21 insertions, 21 deletions
diff --git a/kpresenter/KPrTextObject.cpp b/kpresenter/KPrTextObject.cpp
index 54934755..6c16133e 100644
--- a/kpresenter/KPrTextObject.cpp
+++ b/kpresenter/KPrTextObject.cpp
@@ -239,7 +239,7 @@ void KPrTextObject::saveOasisMarginElement( KoGenStyle &styleobjectauto ) const
if ( bright != 0.0 )
styleobjectauto.addPropertyPt("fo:padding-right", bright );
- //add vertical tqalignment
+ //add vertical alignment
switch( m_textVertAlign )
{
case KP_TOP:
@@ -272,15 +272,15 @@ void KPrTextObject::loadOasis(const TQDomElement &element, KoOasisContext& conte
if( styleStack.hasAttributeNS( KoXmlNS::fo, "padding-right" ) )
bright = KoUnit::parseValue( styleStack.attributeNS( KoXmlNS::fo, "padding-right" ) );
kdDebug()<<" KPrTextObject::loadOasis : btp :"<<btop<<" bbottom :"<<bbottom<<" bleft :"<<bleft<<" bright :"<<bright<<endl;
- // vertical tqalignment
+ // vertical alignment
if ( styleStack.hasAttributeNS( KoXmlNS::draw, "textarea-vertical-align" ) )
{
- TQString tqalignment = styleStack.attributeNS( KoXmlNS::draw, "textarea-vertical-align" );
- if ( tqalignment == "top" )
+ TQString alignment = styleStack.attributeNS( KoXmlNS::draw, "textarea-vertical-align" );
+ if ( alignment == "top" )
m_textVertAlign= KP_TOP;
- else if ( tqalignment == "middle" )
+ else if ( alignment == "middle" )
m_textVertAlign= KP_CENTER;
- else if ( tqalignment == "bottom" )
+ else if ( alignment == "bottom" )
m_textVertAlign= KP_BOTTOM;
}
kdDebug()<<" vertical Alignment :"<< ( ( m_textVertAlign== KP_TOP ) ? "top" : ( m_textVertAlign== KP_CENTER ) ? "center": "bottom" )<<endl;
@@ -871,7 +871,7 @@ KoTextFormat KPrTextObject::loadFormat( TQDomElement &n, KoTextFormat * refForma
if ( !n.isNull() )
{
TQFontDatabase fdb;
- TQStringList families = fdb.tqfamilies();
+ TQStringList families = fdb.families();
if ( families.findIndex( n.attribute( attrFamily ) ) != -1 )
fn.setFamily( n.attribute( attrFamily ) );
else
@@ -1287,7 +1287,7 @@ void KPrTextObject::recalcPageNum( KPrPage *page )
}
var->resize();
- var->paragraph()->tqinvalidate( 0 ); // size may have changed -> need reformatting !
+ var->paragraph()->invalidate( 0 ); // size may have changed -> need reformatting !
var->paragraph()->setChanged( true );
}
}
@@ -1295,17 +1295,17 @@ void KPrTextObject::recalcPageNum( KPrPage *page )
void KPrTextObject::tqlayout()
{
- tqinvalidate();
+ invalidate();
// Get the thing going though, repainting doesn't call formatMore
m_textobj->formatMore( 2 );
}
-void KPrTextObject::tqinvalidate()
+void KPrTextObject::invalidate()
{
- //kdDebug(33001) << "KWTextFrameSet::tqinvalidate " << getName() << endl;
+ //kdDebug(33001) << "KWTextFrameSet::invalidate " << getName() << endl;
m_textobj->setLastFormattedParag( textDocument()->firstParag() );
textDocument()->formatter()->setViewFormattingChars( m_doc->viewFormattingChars() );
- textDocument()->tqinvalidate(); // lazy tqlayout, real update follows upon next tqrepaint
+ textDocument()->invalidate(); // lazy tqlayout, real update follows upon next repaint
}
// For the "paragraph after paragraph" effect
@@ -1451,13 +1451,13 @@ KPrTextView * KPrTextObject::createKPTextView( KPrCanvas * _canvas, bool temp )
void KPrTextObject::removeHighlight ()
{
- m_textobj->removeHighlight( true /*tqrepaint*/ );
+ m_textobj->removeHighlight( true /*repaint*/ );
}
-void KPrTextObject::highlightPortion( KoTextParag * parag, int index, int length, KPrCanvas* canvas, bool tqrepaint, KDialogBase* dialog )
+void KPrTextObject::highlightPortion( KoTextParag * parag, int index, int length, KPrCanvas* canvas, bool repaint, KDialogBase* dialog )
{
- m_textobj->highlightPortion( parag, index, length, tqrepaint );
- if ( tqrepaint )
+ m_textobj->highlightPortion( parag, index, length, repaint );
+ if ( repaint )
{
KPrDocument* doc = canvas->getView()->kPresenterDoc();
@@ -1616,7 +1616,7 @@ void KPrTextObject::slotAfterFormatting( int bottom, KoTextParag* lastFormatted,
// Do recalculate the new available height though
slotAvailableHeightNeeded();
m_doc->updateRuler();
- m_doc->tqrepaint( true );
+ m_doc->repaint( true );
*abort = false;
}
}
@@ -1864,9 +1864,9 @@ void KPrTextView::updateUI( bool updateFormat, bool force )
KoTextView::updateUI( updateFormat, force );
// Paragraph settings
KoTextParag * parag = static_cast<KoTextParag*>( cursor()->parag());
- if ( m_paragLayout.tqalignment != parag->resolveAlignment() || force ) {
- m_paragLayout.tqalignment = parag->resolveAlignment();
- m_canvas->getView()->alignChanged( m_paragLayout.tqalignment );
+ if ( m_paragLayout.alignment != parag->resolveAlignment() || force ) {
+ m_paragLayout.alignment = parag->resolveAlignment();
+ m_canvas->getView()->alignChanged( m_paragLayout.alignment );
}
// Counter
@@ -2356,7 +2356,7 @@ void KPrTextView::insertVariable( KoVariable *var, KoTextFormat *format, bool re
customItemsMap );
if ( refreshCustomMenu && var->type() == VT_CUSTOM )
kpTextObject()->kPresenterDocument()->refreshMenuCustomVariable();
- kpTextObject()->kPresenterDocument()->tqrepaint( kpTextObject() );
+ kpTextObject()->kPresenterDocument()->repaint( kpTextObject() );
}
}